<?php
$translations = array(
	'General_Locale' => 'zh_CN.UTF-8',
	'General_TranslatorName' => 'Marine.Ming',
	'General_TranslatorEmail' => 'albert.einstain@gmail.com',
	'General_EnglishLanguageName' => 'Simplified Chinese',
	'General_OriginalLanguageName' => '简体中文',
	'General_HelloUser' => '您好， %s！',
	'General_OpenSourceWebAnalytics' => '开源网站流量分析工具',
	'General_Dashboard' => '控制台',
	'General_DashboardForASpecificWebsite' => '特定网站控制台',
	'General_MultiSitesSummary' => '所有网站',
	'General_AllWebsitesDashboard' => '所有网站控制台',
	'General_API' => 'API',
	'General_Widgets' => '组件',
	'General_Settings' => '设置',
	'General_GiveUsYourFeedback' => '提交您的意见反馈！',
	'General_Unknown' => '未知的',
	'General_Required' => '%s 个请求数',
	'General_NotValid' => '%s 无效',
	'General_Error' => '错误',
	'General_Warning' => '警告',
	'General_BackToHomepage' => '返回 Piwik 首页',
	'General_Yes' => '是',
	'General_No' => '否',
	'General_Delete' => '删除',
	'General_Report' => '报告',
	'General_Edit' => '编辑',
	'General_Download' => '下载',
	'General_Ok' => 'OK',
	'General_Close' => '关闭',
	'General_OrCancel' => '或 %s 取消 %s',
	'General_Logout' => '注销',
	'General_Username' => '使用者名称',
	'General_Description' => '描述',
	'General_Done' => '完成',
	'General_Name' => '姓名',
	'General_Value' => '数值',
	'General_Details' => '详情',
	'General_Default' => '默认',
	'General_Date' => '日期',
	'General_Period' => '期间',
	'General_Today' => '今日',
	'General_Yesterday' => '昨天',
	'General_CurrentWeek' => '本周',
	'General_CurrentMonth' => '本月',
	'General_CurrentYear' => '今年',
	'General_DateRange' => '日期范围:',
	'General_LoadingData' => '加载数据中...',
	'General_Loading_js' => '载入中...',
	'General_GoTo' => '前往 %s',
	'General_Next' => '下一页',
	'General_Previous' => '上一页',
	'General_Search' => '搜索',
	'General_Others' => '其他',
	'General_Table' => '表格',
	'General_Piechart' => '圆饼图',
	'General_TagCloud' => '标签云',
	'General_VBarGraph' => '直方图',
	'General_SaveImageOnYourComputer_js' => '将图片保存至我的电脑，在图片上点选鼠标右键然后选择"将图片另存为..."',
	'General_Refresh' => '刷新',
	'General_Visitors' => '访客',
	'General_ExportThisReport' => '将此资料导出为其他格式',
	'General_ExportAsImage_js' => '导出为图片',
	'General_Export' => '导出',
	'General_YourChangesHaveBeenSaved' => '您的变更已保存。',
	'General_ErrorRequest' => '意外状况！于请求期间发生问题，请再次尝试！',
	'General_ColumnNbUniqVisitors' => '绝对唯一访客数',
	'General_ColumnNbVisits' => '访问次数',
	'General_ColumnPercentageVisits' => '% 个访客',
	'General_ColumnNbActions' => '活动量',
	'General_ColumnMaxActions' => '单次访问的最大活动量',
	'General_ColumnSumVisitLength' => '网站停留时间 (以秒为单位)',
	'General_ColumnLabel' => '标签',
	'General_ColumnConversionRate' => '转换率',
	'General_ColumnActionsPerVisit' => '各个访问的活动量',
	'General_VisitDuration' => '平均访问时间（以秒为单位）',
	'General_ColumnAvgTimeOnSite' => '平均网站停留时间',
	'General_ColumnBounceRate' => '跳出率',
	'General_ColumnExitRate' => '退出率',
	'General_ColumnPageviews' => '浏览量',
	'General_ColumnUniquePageviews' => '绝对不重复浏览量',
	'General_ColumnBounces' => '跳出',
	'General_ColumnEntrances' => '主要目标网页',
	'General_ColumnExits' => '主要退出网页',
	'General_ColumnAverageTimeOnPage' => '平均网站停留时间',
	'General_ColumnValuePerVisit' => '每次访问价值',
	'General_ColumnVisitsWithConversions' => '访问转换',
	'General_YearsDays' => '%1$s 年 %2$s 天',
	'General_DaysHours' => '%1$s 天 %2$s 小時',
	'General_HoursMinutes' => '%1$s 小時 %2$s 分',
	'General_MinutesSeconds' => '%1$s 分 %2$s 秒',
	'General_Seconds' => '%s 秒',
	'General_Save' => '保存',
	'General_ForExampleShort' => '例如',
	'General_YouMustBeLoggedIn' => '您必须登录才能存取这个功能。',
	'General_Website' => '网站',
	'General_GeneralSettings' => '一般设定',
	'General_AllowPiwikArchivingToTriggerBrowser' => '当报告在浏览器里显示时，允许 Piwik 触发整理',
	'General_ArchivingInlineHelp' => '对于中或高流量的网站，建议停用 Piwik 整理触发浏览器。反之，我们建议您设定一个工作排程(Cron job)，每小时处理 Piwik 报告。',
	'General_ArchivingTriggerDescription' => '推荐大型的 Piwik 安裝，您需要%s设定一个工作排程(Cron job)%s来自动处理报告。',
	'General_SeeTheOfficialDocumentationForMoreInformation' => '查看%s官方文件%s取得更多资讯',
	'General_NSeconds' => '%s 秒处理一次',
	'General_SmallTrafficYouCanLeaveDefault' => '对于低流量的网站，您可以使用预设的 %s 秒，然后即时存取所有报告。',
	'General_MediumToHighTrafficItIsRecommendedTo' => '对于中或高流量的网站，我们建议最多每隔半小时(%s 秒)或每小时(%s 秒)处理报告。',
	'General_RequiresFlash' => '在 Piwik 显示图表必須有 Flash',
	'General_GraphHelp' => '更多关于 Piwik 显示图标的资讯',
	'General_NoDataForGraph' => '因无数据无法显示绘图',
	'General_NoDataForTagCloud' => '因无数据无法显示标签云！',
	'General_DisplaySimpleTable' => '显示简易表格',
	'General_DisplayTableWithMoreMetrics' => '显示更多数据表',
	'General_DisplayTableWithGoalMetrics' => '显示目标数据表',
	'General_YouAreViewingDemoShortMessage' => '您正在浏览 Piwik 范例',
	'General_DownloadFullVersion' => '%1$s下載%2$s完整版本！來吧 %3$s',
	'General_NewUpdatePiwikX' => '新的更新：Piwik %s',
	'General_AboutPiwikX' => '关于 Piwik %s',
	'General_PiwikXIsAvailablePleaseUpdateNow' => 'Piwik %1$s 已经可用。 %2$s 请立即更新！%3$s （查看 %4$s 与%5$s 的差异）。',
	'General_PiwikXIsAvailablePleaseNotifyPiwikAdmin' => '%s 已经可用。请通知网站管理员。',
	'General_NewReportsWillBeProcessedByCron' => '当 Piwik 存档无法由浏览器触发时，新的报表將以 crontab 处理。',
	'General_ReportsWillBeProcessedAtMostEveryHour' => '因此，报告最多每隔一小時将处理一次。',
	'General_IfArchivingIsFastYouCanSetupCronRunMoreOften' => '假设在您的设置下存档相当顺畅，您可以设置并让它的执行更频繁。',
	'General_BackToPiwik' => '返回 Piwik',
	'General_ClickHere' => '点击查看更多信息',
	'General_ShortMonth_1' => '一月',
	'General_ShortMonth_2' => '二月',
	'General_ShortMonth_3' => '三月',
	'General_ShortMonth_4' => '四月',
	'General_ShortMonth_5' => '五月',
	'General_ShortMonth_6' => '六月',
	'General_ShortMonth_7' => '七月',
	'General_ShortMonth_8' => '八月',
	'General_ShortMonth_9' => '九月',
	'General_ShortMonth_10' => '十月',
	'General_ShortMonth_11' => '十一月',
	'General_ShortMonth_12' => '十二月',
	'General_LongMonth_1' => '一月',
	'General_LongMonth_2' => '二月',
	'General_LongMonth_3' => '三月',
	'General_LongMonth_4' => '四月',
	'General_LongMonth_5' => '五月',
	'General_LongMonth_6' => '六月',
	'General_LongMonth_7' => '七月',
	'General_LongMonth_8' => '八月',
	'General_LongMonth_9' => '九月',
	'General_LongMonth_10' => '十月',
	'General_LongMonth_11' => '十一月',
	'General_LongMonth_12' => '十二月',
	'General_ShortDay_1' => '周一',
	'General_ShortDay_2' => '周二',
	'General_ShortDay_3' => '周三',
	'General_ShortDay_4' => '周四',
	'General_ShortDay_5' => '周五',
	'General_ShortDay_6' => '周六',
	'General_ShortDay_7' => '周日',
	'General_LongDay_1' => '星期一',
	'General_LongDay_2' => '星期二',
	'General_LongDay_3' => '星期三',
	'General_LongDay_4' => '星期四',
	'General_LongDay_5' => '星期五',
	'General_LongDay_6' => '星期六',
	'General_LongDay_7' => '星期日',
	'General_Daily' => '每天',
	'General_Weekly' => '每周',
	'General_Monthly' => '每月',
	'General_ConfigFileIsNotWritable' => 'Piwik 配置文件 %s 无法写入，您的变更将无法保存。%s 请变更配置文件的权限让它可被写入。',
	'General_ExceptionDatabaseVersion' => '您的 %1$s 版本为 %2$s ，但 Piwik 需求至少要 %3$s。',
	'General_ExceptionIncompatibleClientServerVersions' => '您的 %1$s 客戶端版本為 %2$s，与服务器版本 %3%s 不相容。',
	'General_ExceptionMissingFile' => '遗失文件: %s',
	'General_ExceptionFilesizeMismatch' => '文件大小不符: %1$s （预计长度: %2$s, 找到: %3$s）',
	'General_ExceptionFileIntegrity' => '完整性检查失败: %s',
	'General_ExceptionNonceMismatch' => '无法验证此表单的安全性。',
	'General_PleaseSpecifyValue' => '请为 \'%s\' 设定一个數值。',
	'General_ExceptionMethodNotFound' => '\'%s\' 不存在或不适用于模組 \'%s\' 里。',
	'General_ExceptionInvalidRendererFormat' => '\'%s\' 是不合法的。尝试以下任一来取代: %s 。',
	'General_ExceptionInvalidReportRendererFormat' => '报告格式 %s 无效，尝试以下内容 %s',
	'General_ExceptionInvalidPeriod' => '目前不支持 \'%s\' 。尝试以下任一来取代: %s',
	'General_ExceptionInvalidDateRange' => '\'%s\' 不是一个正确的日期范围。它应该拥有以下格式: %s。',
	'General_ExceptionGoalNotFound' => '目标 id = %s 找不到。',
	'General_ExceptionUndeletableFile' => '无法刪除 %s',
	'General_ExceptionPrivilege' => '您无法存取这个资源，必须要一个 %s 权限。',
	'General_ExceptionPrivilegeAtLeastOneWebsite' => '您无法存取这个资源，必须至少要一个网站的 %s 权限。',
	'General_ExceptionPrivilegeAccessWebsite' => '您无法存取这个资源，必须拥有网站 ID = %d 的 %s 权限。',
	'General_ExceptionInvalidArchiveTimeToLive' => '今日整理时间必须是一个大于 0 秒的数字',
	'General_ExceptionConfigurationFileNotFound' => '配置文件 {%s} 找不到。',
	'General_ExceptionUnreadableFileDisabledMethod' => '配置文件 {%s} 无法读取。您的主机空间可能停用 %s。',
	'General_ExceptionInvalidToken' => '符号不合法。',
	'General_ExceptionInvalidDateFormat' => '日期格式必须为: %s 或任何被 %s 函数支持的关键字（查看 %s 取得更多资讯）',
	'General_ExceptionLanguageFileNotFound' => '语系文件 \'%s\' 找不到。',
	'General_ExceptionUnableToStartSession' => '无法启动会话',
	'General_WarningFileIntegritySkipped' => '检测到开发环境。跳过文件完整性检查。',
	'General_WarningFileIntegrityNoManifest' => '缺少 manifest.inc.php 所以文件完整性检查无法完成。',
	'General_WarningFileIntegrityNoMd5file' => '缺少 md5_file() 函式所以文件完整性检查无法完成。',
	'General_FileIntegrityWarningExplanation' => '文件完整性检查错误且报告了一些问题。这大多是因为上传了部分或错误的 Piwik 文件所致。您应该使用 BINARY 模式重新上传所有的 Piwik 文件然后重新整理此页面直到它沒有显示任何错误。',
	'General_UseSMTPServerForEmail' => '使用 SMTP 服务器来传送 E-mail',
	'General_SmtpServerAddress' => 'SMTP 服务器地址',
	'General_SmtpPort' => 'SMTP 端口',
	'General_AuthenticationMethodSmtp' => 'SMTP 验证方法',
	'General_SmtpUsername' => 'SMTP 使用者名称',
	'General_SmtpPassword' => 'SMTP 密码',
	'General_SmtpEncryption' => 'SMTP 加密',
	'General_SelectYesIfYouWantToSendEmailsViaServer' => '如果您想通过一个 named server 来寄送电子邮件，而不是 mail 函式的话请选择 "Yes"',
	'General_OptionalSmtpPort' => '可选项，默认是未加密和TLS SMTP使用25端口，SSL加密使用465端口',
	'General_OnlyUsedIfUserPwdIsSet' => '只在使用者名称 / 密码设定后才会生效，如果您不确定要使用何种方法，请询问您的提供商。',
	'General_OnlyEnterIfRequired' => '只在您的 SMTP 服务器需要使用者名称时才需要输入',
	'General_OnlyEnterIfRequiredPassword' => '只在您的 SMTP 服务器需要密码时才需要输入',
	'General_WarningPasswordStored' => '%s警告:%s 此密码将被保存在配置文件中，且每个能存取它的人都看得到。',
	'General_EncryptedSmtpTransport' => '输入你的SMTP服务器需要的传输加密方式',
	'General_InvalidResponse' => '接收到的资料是无效的。',
	'General_ChooseLanguage' => '选择语系',
	'General_ChoosePeriod' => '选择期间',
	'General_ChooseWebsite' => '选择网站',
	'General_Language' => '语系',
	'General_PleaseUpdatePiwik' => '请更新您的 Piwik',
	'General_RequestTimedOut' => '%s 资料请求超时。请再试一次。',
	'General_Help' => '帮助',
	'Actions_PluginDescription' => '关于页面浏览量、离开链接和下载。离开链接及下载的追踪是自动的！',
	'Actions_Actions' => '进站活动',
	'Actions_SubmenuPages' => '浏览页面',
	'Actions_SubmenuPagesEntry' => '目标网页',
	'Actions_SubmenuPagesExit' => '退出网页',
	'Actions_SubmenuPageTitles' => '网页标题',
	'Actions_SubmenuOutlinks' => '离开链接',
	'Actions_SubmenuDownloads' => '下载',
	'Actions_ColumnClicks' => '点击次数',
	'Actions_ColumnUniqueClicks' => '绝对不重复点击数',
	'Actions_ColumnDownloads' => '下载次数',
	'Actions_ColumnUniqueDownloads' => '绝对不重复下载次数',
	'Actions_ColumnPageName' => '页面名称',
	'Actions_ColumnPageURL' => '页面网址',
	'Actions_ColumnClickedURL' => '点击的 URL 地址',
	'Actions_ColumnDownloadURL' => '下载的 URL 地址',
	'AnonymizeIP_PluginDescription' => '隐藏访客IP位址最后一个字符以符合您的当地隐私条例/政策。',
	'API_PluginDescription' => '所有在 Piwik 的资料都能使用简单的 APIs 取得。这个插件是网页服务的切入点，让您可以以 xml, json, php, csv 及其他格式取得网站分析资料。',
	'API_QuickDocumentationTitle' => 'API 快速说明文件',
	'API_GenerateVisits' => '如果您今天还沒有任何资料，您可以先使用 %s 插件来产生一些数据。您可以启用 %s 外挂，然后点击在 Piwik 管理员区域里的\'产生访客\'选单。',
	'API_MoreInformation' => '取得更多关于 Piwik APIs 的资讯，请前往 %sPiwik API 指引%s 与 %s Piwik API 參考资料%s。',
	'API_UserAuthentication' => '使用者验证',
	'API_UsingTokenAuth' => '如果您想从程序、工作排程在 %s 请求资料。%s 您需要新增一个 %s 字符串至 API 调用网址来运行验证。',
	'API_KeepTokenSecret' => 'token_auth 如您的帐号和密码般重要，%s请不要公开它%s！',
	'API_LoadedAPIs' => '已成功载入 %s 个 API',
	'CoreAdminHome_PluginDescription' => 'Piwik 插件管理',
	'CoreAdminHome_MenuGeneralSettings' => '一般设置',
	'CoreAdminHome_Administration' => '管理',
	'CoreHome_PluginDescription' => '网站分析报告结构。',
	'CoreHome_WebAnalyticsReports' => '网站分析报告',
	'CoreHome_JavascriptDisabled' => '使用 Piwik 的标准视图时必须启用 JavaScript。<br />然而，看来您的浏览器已停用或不支持 JavaScript。<br />若要使用标准视图，请变更您的浏览器选项并启用 JavaScript, 然后%1$s重试一次%2$s。<br />',
	'CoreHome_ThereIsNoDataForThisReport' => '此报表沒有资料。',
	'CoreHome_CategoryNoData' => '类别无数据！ 尝试使用 "包含所有个体"！',
	'CoreHome_ShowJSCode' => '显示 Javascript 统计代码',
	'CoreHome_PageOf_js' => '%s of %s',
	'CoreHome_PeriodDay' => '日统计',
	'CoreHome_PeriodWeek' => '周统计',
	'CoreHome_PeriodMonth' => '月统计',
	'CoreHome_PeriodYear' => '年统计',
	'CoreHome_PeriodDays' => '天',
	'CoreHome_PeriodWeeks' => '周',
	'CoreHome_PeriodMonths' => '月',
	'CoreHome_PeriodYears' => '年',
	'CoreHome_DaySu_js' => '日',
	'CoreHome_DayMo_js' => '一',
	'CoreHome_DayTu_js' => '二',
	'CoreHome_DayWe_js' => '三',
	'CoreHome_DayTh_js' => '四',
	'CoreHome_DayFr_js' => '五',
	'CoreHome_DaySa_js' => '六',
	'CoreHome_ShortDay_1_js' => '周日',
	'CoreHome_ShortDay_2_js' => '周一',
	'CoreHome_ShortDay_3_js' => '周二',
	'CoreHome_ShortDay_4_js' => '周三',
	'CoreHome_ShortDay_5_js' => '周四',
	'CoreHome_ShortDay_6_js' => '周五',
	'CoreHome_ShortDay_7_js' => '周六',
	'CoreHome_LongDay_1_js' => '星期日',
	'CoreHome_LongDay_2_js' => '星期一',
	'CoreHome_LongDay_3_js' => '星期二',
	'CoreHome_LongDay_4_js' => '星期三',
	'CoreHome_LongDay_5_js' => '星期四',
	'CoreHome_LongDay_6_js' => '星期五',
	'CoreHome_LongDay_7_js' => '星期六',
	'CoreHome_ShortMonth_1_js' => '一',
	'CoreHome_ShortMonth_2_js' => '二',
	'CoreHome_ShortMonth_3_js' => '三',
	'CoreHome_ShortMonth_4_js' => '四',
	'CoreHome_ShortMonth_5_js' => '五',
	'CoreHome_ShortMonth_6_js' => '六',
	'CoreHome_ShortMonth_7_js' => '七',
	'CoreHome_ShortMonth_8_js' => '八',
	'CoreHome_ShortMonth_9_js' => '九',
	'CoreHome_ShortMonth_10_js' => '十',
	'CoreHome_ShortMonth_11_js' => '十一',
	'CoreHome_ShortMonth_12_js' => '十二',
	'CoreHome_MonthJanuary_js' => '一月',
	'CoreHome_MonthFebruary_js' => '二月',
	'CoreHome_MonthMarch_js' => '三月',
	'CoreHome_MonthApril_js' => '四月',
	'CoreHome_MonthMay_js' => '五月',
	'CoreHome_MonthJune_js' => '六月',
	'CoreHome_MonthJuly_js' => '七月',
	'CoreHome_MonthAugust_js' => '八月',
	'CoreHome_MonthSeptember_js' => '九月',
	'CoreHome_MonthOctober_js' => '十月',
	'CoreHome_MonthNovember_js' => '十一月',
	'CoreHome_MonthDecember_js' => '十二月',
	'CorePluginsAdmin_PluginDescription' => '插件管理界面。',
	'CorePluginsAdmin_Plugins' => '插件',
	'CorePluginsAdmin_PluginsManagement' => '插件管理',
	'CorePluginsAdmin_MainDescription' => '插件延伸并扩展了 Piwik 的功能。 当一个插件安装了以后，您可以在这里启用或停用它。',
	'CorePluginsAdmin_Plugin' => '插件',
	'CorePluginsAdmin_Version' => '版本',
	'CorePluginsAdmin_Status' => '状态',
	'CorePluginsAdmin_Action' => '动作',
	'CorePluginsAdmin_PluginHomepage' => '插件首页',
	'CorePluginsAdmin_Activated' => '已激活的',
	'CorePluginsAdmin_Active' => '活动的',
	'CorePluginsAdmin_Inactive' => '不活动的',
	'CorePluginsAdmin_Deactivate' => '停用',
	'CorePluginsAdmin_Activate' => '启用',
	'CorePluginsAdmin_MenuPlugins' => '插件',
	'CoreUpdater_PluginDescription' => 'Piwik 更新机制',
	'CoreUpdater_UpdateTitle' => 'Piwik › 升级',
	'CoreUpdater_YourDatabaseIsOutOfDate' => '您的 Piwik 数据库已经太旧了，所以您必须先升级才可以继续！',
	'CoreUpdater_TheFollowingPluginsWillBeUpgradedX' => '以下插件将被升级： %s！',
	'CoreUpdater_NoteForLargePiwikInstances' => '大型 Piwik 网站重要注意事项',
	'CoreUpdater_TheUpgradeProcessMayFailExecuteCommand' => '如果您有一个大型的 Piwik 数据库，在浏览器内更新可能需要花费很长时间。在此情況下，您可以通过以下指令来执行更新：%s',
	'CoreUpdater_YouCouldManuallyExecuteSqlQueries' => '如果您无法使用指令来更新且 Piwik 升级失败（数据库超时、浏览器超时或任何问题），您可以手动执行 SQL 语句来更新 Piwik.',
	'CoreUpdater_ClickHereToViewSqlQueries' => '选择这里来查看并复制即将执行的 SQL 语句列表',
	'CoreUpdater_NoteItIsExpectedThatQueriesFail' => '注意：如果您手动执行这些查询，预计当中会有一些错误。在此情況下，只需忽略错误，然后执行以下列表。',
	'CoreUpdater_ReadyToGo' => '准备好了吗？',
	'CoreUpdater_TheUpgradeProcessMayTakeAWhilePleaseBePatient' => '升级过程可能需要一段时间，所以请耐心等待！',
	'CoreUpdater_UpgradePiwik' => '升级 Piwik',
	'CoreUpdater_ErrorDIYHelp' => '如果您是进阶用戶且在升级数据库时发生错误：',
	'CoreUpdater_ErrorDIYHelp_1' => '识别并修复问题来源（例如 memory_limit 或 max_execution_time）',
	'CoreUpdater_ErrorDIYHelp_2' => '执行升级失败时剩余的 SQL 语法',
	'CoreUpdater_ErrorDIYHelp_3' => '手动更新您的 Piwik 数据库內的 \'option\' 数据表，version_core 的设定值更新失败',
	'CoreUpdater_ErrorDIYHelp_4' => '重新执行更新程序（通过浏览器或指令列）来继续剩余的更新',
	'CoreUpdater_ErrorDIYHelp_5' => '报告问题（或解決办法）以改善 Piwik',
	'CoreUpdater_HelpMessageContent' => '请检查 %s Piwik FAQ %s ，在其中已试图解释最常见的升级过程中的错误。 %s 请询问您的系统管理员 - 他们可以协助您解决几乎所有有关您的服务器或 MySQL 设定的问题！',
	'CoreUpdater_CriticalErrorDuringTheUpgradeProcess' => '在升级过程中发生严重的错误：',
	'CoreUpdater_HelpMessageIntroductionWhenError' => '以上是核心的错误讯息。它应有助于解释原因，但如果您需要进一步的说明，请：',
	'CoreUpdater_HelpMessageIntroductionWhenWarning' => '此次升级成功完成，但在过程中有发生一些问题，请仔细阅读上面的详细说明。如需更进一步的说明：',
	'CoreUpdater_UpgradeComplete' => '升级完成！',
	'CoreUpdater_WarningMessages' => '警告讯息：',
	'CoreUpdater_ErrorDuringPluginsUpdates' => '插件升级期间发生错误：',
	'CoreUpdater_WeAutomaticallyDeactivatedTheFollowingPlugins' => '我们自动停用了以下的插件： %s',
	'CoreUpdater_PiwikHasBeenSuccessfullyUpgraded' => 'Piwik 已成功升级！',
	'CoreUpdater_ContinueToPiwik' => '继续 Piwik',
	'CoreUpdater_YouMustDownloadPackageOrFixPermissions' => 'Piwik 无法覆盖您之前的安裝。您可以直接修改目录/文件权限，或是下载压缩包然后手动安裝 %s 版本：',
	'CoreUpdater_UpdateHasBeenCancelledExplanation' => 'Piwik 一键升级已被取消。如果您无法修正以上的错误信息，建议您手动升级 Piwik。%1$s 请查看 %2$s升级文件%3$s 来开始吧！',
	'CoreUpdater_DownloadingUpdateFromX' => '从 %s 下载更新中',
	'CoreUpdater_UnpackingTheUpdate' => '正在解压缩更新',
	'CoreUpdater_VerifyingUnpackedFiles' => '正在解压缩后的升级文件',
	'CoreUpdater_CreatingBackupOfConfigurationFile' => '建立一個配置文件的备份于 %s',
	'CoreUpdater_InstallingTheLatestVersion' => '正在安装最新版本中',
	'CoreUpdater_PiwikUpdatedSuccessfully' => 'Piwik 已成功升级！',
	'CoreUpdater_EmptyDatabaseError' => '数据库 %s 是空的。您可能要编辑或移除您的 Piwik 配置文件。',
	'CoreUpdater_ExceptionAlreadyLatestVersion' => '您的 Piwik 版本 %s 是最新的。',
	'CoreUpdater_ExceptionArchiveIncompatible' => '不相容的文件： %s',
	'CoreUpdater_ExceptionArchiveEmpty' => '空的文件。',
	'CoreUpdater_ExceptionArchiveIncomplete' => '文件是不完整的：遗失某些文件（例如 %s）。',
	'Dashboard_PluginDescription' => '您的网站分析控制台。您可以自动您的控制台：新增新的模組、变更您的模組排序。每位使用者可以存取他们自定义的控制台。',
	'Dashboard_Dashboard' => '控制台',
	'Dashboard_DeleteWidgetConfirm' => '您确定要从控制台中删除此小工具吗？',
	'Dashboard_SelectWidget' => '请选取小工具',
	'Dashboard_Close_js' => '关闭',
	'Dashboard_TitleWidgetInDashboard_js' => '控制台中已存在此小工具',
	'Dashboard_TitleClickToAdd_js' => '增加至控制台',
	'Dashboard_LoadingWidget_js' => '加载小工具中，请稍候...',
	'Dashboard_WidgetNotFound_js' => '找不到小工具',
	'DBStats_PluginDescription' => '这个插件能报告 Piwik 的数据表使用情况。',
	'DBStats_DatabaseUsage' => '数据库使用状况',
	'DBStats_MainDescription' => 'Piwik 在MySQL中保存您的所有网站分析数据。 目前， Piwik 数据表已经使用了 %s！',
	'DBStats_LearnMore' => '了解更多关于 Piwik 如何处理数据以及使 Piwik 在中高流量的网站上运作事宜，请查阅说明文件 %s。',
	'DBStats_Table' => '数据表',
	'DBStats_RowCount' => '行计算',
	'DBStats_DataSize' => '占用空间',
	'DBStats_IndexSize' => '索引空间大小',
	'DBStats_TotalSize' => '总容量',
	'ExampleAPI_PluginDescription' => '范例插件：如何为您的插件建立一个 API, 然后將多种格式的资料导出且无须任何源码？',
	'ExampleFeedburner_PluginDescription' => '范例插件：如何在控制台里以模组来显示您的 Feedburner 订阅者？',
	'ExampleRssWidget_PluginDescription' => '范例插件：如何建立一個新模組來读取 RSS feed？',
	'ExampleUI_PluginDescription' => '范例插件：这个插件让您了解如何使 Piwik UI 运作：建立数据表、图表等等。',
	'Feedback_PluginDescription' => '传送您的意见反馈給 Piwik 小組。与我们分享您的点子及建议！',
	'Feedback_DoYouHaveBugReportOrFeatureRequest' => '您有一个bug报告或功能请求？',
	'Feedback_ViewAnswersToFAQ' => '至 %s常见问题%s 寻找答案',
	'Feedback_WhyAreMyVisitsNoTracked' => '为什么我的访问沒有被追踪？',
	'Feedback_HowToExclude' => '如何排除追踪我的访问记录？',
	'Feedback_WhyWrongCountry' => '为什么 Piwik 显示了错误的来源国家？',
	'Feedback_HowToAnonymizeIP' => '如何在我的数据库里屏蔽访客的 IP 位址？',
	'Feedback_VisitTheForums' => '访问 %s 论坛%s',
	'Feedback_LearnWaysToParticipate' => '了解所有您可以 %s 参与%s 的方法',
	'Feedback_SpecialRequest' => '您对于 Piwik 小组有特殊的请求？',
	'Feedback_ContactThePiwikTeam' => '联系 Piwik 小组！',
	'Feedback_IWantTo' => '我想要：',
	'Feedback_CategoryShareStory' => '分享一个 Piwik 成功故事',
	'Feedback_CategorySponsor' => '赞助 Piwik',
	'Feedback_CategoryHire' => '雇佣一位 Piwik 顾问',
	'Feedback_CategorySecurity' => '报告一个安全性问题',
	'Feedback_MyEmailAddress' => '我的 Email 地址：',
	'Feedback_MyMessage' => '我的信息：',
	'Feedback_DetailsPlease' => '（请包含细节）',
	'Feedback_SendFeedback' => '送出意见',
	'Feedback_ManuallySendEmailTo' => '请手动寄送您的信息至',
	'Feedback_MessageSent' => '您的信息已寄给 Piwik 小組。',
	'Feedback_ThankYou' => '谢谢您协助我们使 Piwik 变得更好！',
	'Feedback_ThePiwikTeam' => 'Piwik 小组',
	'Feedback_ExceptionBodyLength' => '信息至少要有 %s 的字符以上。',
	'Feedback_ExceptionNoUrls' => '信息不能包含一个网址，由此避免垃圾信息。',
	'Goals_Goals' => '目标',
	'Goals_GoalsOverview' => '目标概述',
	'Goals_GoalsManagement' => '目标管理',
	'Goals_PluginDescription' => '建立目标然后查看关于您的目标转换率报表：时间的演变趋势、每次访问的收入、每个关键字等等。',
	'Goals_ColumnConversions' => '转换',
	'Goals_ColumnRevenue' => '收益',
	'Goals_GoalX' => '目标 %s',
	'Goals_OverallRevenue' => '%s 总收益',
	'Goals_OverallConversionRate' => '%s 总转换率（访问一个完整的目标）',
	'Goals_Conversions' => '%s 转换数',
	'Goals_ConversionRate' => '%s 转换率',
	'Goals_NoGoalsNeedAccess' => '只有管理员或超级使用者能为网站新增目标。请询问您的 Piwik 管理员來协助设定您的网站目标。<br />追踪目标是一个绝佳的方式，帮忙了解及最大化您的网站效益！',
	'Goals_AddNewGoal' => '新增一个新的目标',
	'Goals_AddNewGoalOrEditExistingGoal' => '%s新增一个新的目标%s 或 %s编辑%s 已存在的目标',
	'Goals_AddGoal_js' => '新增目标',
	'Goals_UpdateGoal_js' => '更新目标',
	'Goals_DeleteGoalConfirm_js' => '您確定要刪除目标 %s ？',
	'Goals_CreateNewGOal' => '建立一个新的目标',
	'Goals_ViewAndEditGoals' => '查看和编辑目标',
	'Goals_GoalName' => '目标名称',
	'Goals_GoalIsTriggered' => '目标触发',
	'Goals_GoalIsTriggeredWhen' => '目标触发当',
	'Goals_WhenVisitors' => '当访客',
	'Goals_WhereThe' => '位于',
	'Goals_Manually' => '手动',
	'Goals_ManuallyTriggeredUsingJavascriptFunction' => '手动触发的目标是使用 JavaScript API trackGoal()',
	'Goals_VisitUrl' => '访问特定网址（页面或页面群組）',
	'Goals_URL' => '网址',
	'Goals_Filename' => '文件名称',
	'Goals_ExternalWebsiteUrl' => '外部网站网址',
	'Goals_Download' => '下载一个文件',
	'Goals_ClickOutlink' => '选择一个链接到外部网站',
	'Goals_Optional' => '（选项）',
	'Goals_WhereVisitedPageManuallyCallsJavascriptTrackerLearnMore' => '在被访问的页面包含一个 JavaScript piwikTracker.trackGoal() 方法（%s知道更多%s）',
	'Goals_DefaultRevenue' => '目标预设收益是',
	'Goals_DefaultRevenueHelp' => '举例来说，访客送出一个联系表单可能平均价值为 $10。Piwik 将帮助您了解您的访客。',
	'Goals_ConversionsOverview' => '转换概述',
	'Goals_BestCountries' => '您的最佳转换国家为：',
	'Goals_BestKeywords' => '您的最佳转换关键字为：',
	'Goals_BestReferers' => '您的最佳转换网站推荐链接为：',
	'Goals_ReturningVisitorsConversionRateIs' => '回访访客转换率为 %s',
	'Goals_NewVisitorsConversionRateIs' => '新訪客转换率为 %s',
	'Goals_Contains' => '有 %s',
	'Goals_IsExactly' => '正是 %s',
	'Goals_MatchesExpression' => '表达式符合 %s',
	'Goals_CaseSensitive' => '大小写符合',
	'Goals_Pattern' => '模式',
	'Goals_ExceptionInvalidMatchingString' => '如果您选择 \'标准符合\'，相符的字符串必须包含一个网址开头 %s. 举例来说，\'%s\' 。',
	'Goals_LearnMoreAboutGoalTrackingDocumentation' => '在使用者文件里找到更多关于 %s Piwik 里的追踪目标 %s。',
	'Installation_PluginDescription' => 'Piwik 的安裝程序。通常只需要安裝一次。如果配置文件 config/config.inc.php 被刪除，那么将会重新安裝。',
	'Installation_Installation' => '安装',
	'Installation_InstallationStatus' => '安装状态',
	'Installation_PercentDone' => '%s %% 已完成',
	'Installation_NoConfigFound' => '无法找到 Piwik 配置文件，而您正尝试存取一个 Piwik 的页面！<br /><b>  » 您可以 <a href=\'index.php\'>立刻安装 Piwik</a></b><br /><small>假如您在之前已安装过 Piwik，并且已有些数据表在您的数据库中，不用担心，您可以重复使用此相同的数据表并保留您现存的数据！</small>',
	'Installation_DatabaseSetup' => '数据库设置',
	'Installation_DatabaseSetupServer' => '数据库服务器',
	'Installation_DatabaseSetupLogin' => '数据库帐号',
	'Installation_DatabaseSetupPassword' => '数据库密码',
	'Installation_DatabaseSetupDatabaseName' => '数据库名称',
	'Installation_DatabaseSetupTablePrefix' => '数据表前綴词',
	'Installation_DatabaseSetupAdapter' => 'Adapter',
	'Installation_DatabaseErrorConnect' => '连接至数据库服务器時发生错误',
	'Installation_DatabaseCheck' => '数据库检查',
	'Installation_DatabaseServerVersion' => '数据库服务器版本',
	'Installation_DatabaseClientVersion' => '数据库客戶端版本',
	'Installation_DatabaseCreation' => '数据库建立',
	'Installation_PleaseFixTheFollowingErrors' => '请修复以下错误',
	'Installation_LargePiwikInstances' => 'Piwik 给予大型网站的协助',
	'Installation_JsTag' => 'Javascript 标签',
	'Installation_JsTagArchivingHelp' => '在一个中或高流量的网站，请查阅<a target="_blank" href="http://piwik.org/docs/setup-auto-archiving/">如何设置自动整理页面</a>来使 Piwik 运作的更顺畅！',
	'Installation_Congratulations' => '恭喜您',
	'Installation_CongratulationsHelp' => '<p>恭喜您！ 您的 Piwik 安装已经完成！</p><p>请确认您的 Javascript 统计代码已插入至您的网页之中，并等候您的首位访客！</p>',
	'Installation_SetupWebsite' => '设定一个网站',
	'Installation_SetupWebSiteName' => '网站名称',
	'Installation_SetupWebSiteURL' => '网站网址',
	'Installation_Timezone' => '网站时区',
	'Installation_SetupWebsiteError' => '当增加此网站时发生了一个错误',
	'Installation_SetupWebsiteSetupSuccess' => '网站 %s 已成功建立！',
	'Installation_SuperUserLogin' => '超级使用者帐号',
	'Installation_Password' => '密码',
	'Installation_PasswordRepeat' => '密码 （再输入一次确认）',
	'Installation_Email' => 'E-mail',
	'Installation_SecurityNewsletter' => '寄给我重要的 Piwik 更新与安全性警告电子邮件通知',
	'Installation_CommunityNewsletter' => '寄给我社区更新的电子邮件通知（如：新插件、新功能等等。）',
	'Installation_PasswordDoNotMatch' => '密码不相符',
	'Installation_Requirements' => 'Piwik 需求',
	'Installation_Optional' => '选项',
	'Installation_Legend' => '说明',
	'Installation_Extension' => '扩展',
	'Installation_SystemCheck' => '检查系统',
	'Installation_SystemCheckPhp' => 'PHP 版本',
	'Installation_SystemCheckExtensions' => '其他需要的扩展组件',
	'Installation_SystemCheckDatabaseHelp' => 'Piwik 需要 mysqli 扩展组件或包含 PDO 及 pdo_mysql 扩展组件。',
	'Installation_SystemCheckPdoAndMysqliHelp' => '在 Linux 服务器上您可以使用以下选项编译 PHP: 在您的php.ini 中 %1$s, 加入以下几行: %2$s',
	'Installation_SystemCheckPhpPdoAndMysqliSite' => '更多资讯：<a style="color:red" href="http://php.net/pdo">PHP PDO</a> 和 <a style="color:red" href="http://php.net/mysqli">MYSQLI</a>.',
	'Installation_SystemCheckWinPdoAndMysqliHelp' => '在 Windows 伺服器上您可以新增以下幾行至您的 php.ini 中: %s',
	'Installation_SystemCheckSplHelp' => '您需要设定及重建 PHP, 然后启用 Standard PHP Library (SPL)。',
	'Installation_SystemCheckZlibHelp' => '您需要设定及重建 PHP, 然后启用"zlib"支持, --with-zlib.',
	'Installation_SystemCheckIconvHelp' => '您需要设定及重建 PHP, 然后启用"iconv"支持, --with-iconv.',
	'Installation_SystemCheckWriteDirs' => '具写入权限的目录',
	'Installation_SystemCheckWriteDirsHelp' => '要在您的 Linux 系统修正这个错误，尝试输入以下的命令',
	'Installation_SystemCheckMemoryLimit' => '内存限制',
	'Installation_SystemCheckMemoryLimitHelp' => '在一个高流量的网站，数据汇整归档过程可能需要更多过于目前所允许使用的内存量！<br />假如有必要的话请查看在您的 php.ini 之中关于 memory_limit 的帮助！',
	'Installation_SystemCheckOpenURL' => '开启网址',
	'Installation_SystemCheckOpenURLHelp' => '新闻订阅、更新通知及一键安装更新功能需要 "curl" 函式，allow_url_fopen=On, 或启用 fsockopen().',
	'Installation_SystemCheckGD' => 'GD > 2.x (图形库)',
	'Installation_SystemCheckGDHelp' => 'Sparklines (小图) 将无法显示！',
	'Installation_SystemCheckFunctions' => '必须函式',
	'Installation_SystemCheckTimeLimitHelp' => '在一个高流量的网站，执行数据汇整归档过程可能需要更多过于目前所允许使用的时间！<br />假如有必要的话请查看在您的 php.ini 之中关于 max_execution_time 的帮助！',
	'Installation_SystemCheckMailHelp' => '意见反馈及忘记密码信息若沒有 mail() 将无法寄送。',
	'Installation_SystemCheckParseIniFileHelp' => '內建的函式在您的空间內已被停用。Piwik 将会尝试模拟这些功能，但可能会造成更多安全性问题。追踪的表现也会受到影响。',
	'Installation_SystemCheckGlobHelp' => '这个內建的函数已被您的主机商停用。Piwik 將尝试模拟这个功能，但可能会遇到更多安全限制。功能可能受到影响。',
	'Installation_SystemCheckDebugBacktraceHelp' => '检查::无法建立模組检查。',
	'Installation_SystemCheckCreateFunctionHelp' => 'Piwik 在callbacks上使用匿名函式。',
	'Installation_SystemCheckEvalHelp' => '必须为 HTML QuickForm 及 Smarty 模板系统。',
	'Installation_SystemCheckMbstring' => 'mbstring',
	'Installation_SystemCheckMbstringExtensionHelp' => 'The mbstring extension is required for multibyte characters in API responses using comma-separated values (CSV) or tab-separated values (TSV).',
	'Installation_SystemCheckMbstringFuncOverloadHelp' => '您应该将 mbstring.func_overload 设定为 "0"。',
	'Installation_SystemCheckFileIntegrity' => '文件完整性',
	'Installation_SystemCheckAutoUpdateHelp' => '注意：Piwik 的一键更新功能必须要有 Piwik 目录及內容的写入权限。',
	'Installation_SystemCheckError' => '发生错误 - 必须先修正，才能再继续',
	'Installation_SystemCheckWarning' => 'Piwik 将正常工作，但某些功能可能无效',
	'Installation_Tables' => '建立数据表中',
	'Installation_TablesFound' => '以下的数据表在数据库之中已存在',
	'Installation_TablesWarningHelp' => '要么就选择重复使用现存的数据表，再不然就选择全新安装，以清除所有现存数据库中的数据！',
	'Installation_TablesReuse' => '重复使用已存在的数据表',
	'Installation_TablesDelete' => '删除已侦测到的数据表',
	'Installation_TablesDeletedSuccess' => '已存在的 Piwik 数据表已成功删除',
	'Installation_TablesCreatedSuccess' => '数据表已成功建立！',
	'Installation_DatabaseCreatedSuccess' => '数据库 %s 已成功建立！',
	'Installation_GoBackAndDefinePrefix' => '返回并为 Piwik 数据表定义一个数据表前綴',
	'Installation_Welcome' => '欢迎使用！',
	'Installation_WelcomeHelp' => '<p>Piwik 是一个让您能够轻易取得您所想要的访客信息的开放原始码网页分析软件！</p><p>此安装过程分为 %s 个简易的步骤，并且将仅花大约 5 分钟的时间！</p>',
	'Installation_ConfigurationHelp' => '您的 Piwik 配置文件看起來似乎损坏了。您可以移除 config/config.ini.php 然后重新安裝，或是修复数据库的连接配置。',
	'Installation_ErrorInvalidState' => '错误：看来您正在尝试停止安裝程序的某个步驟，或是您的 cookies 功能未启用，或者 Piwik 配置文件已经建立。%1$s请确定您的 cookies 功能已启用%2$s然后返回%3$s至安裝程序的初始画面 %4$s。',
	'LanguagesManager_PluginDescription' => '这个插件会显示 Piwik 页面可以使用的语系列表。选择的语言将会被保存在每个使用者的偏好里。',
	'LanguagesManager_AboutPiwikTranslations' => '关于 Piwik 翻译',
	'Live_PluginDescription' => '查看您的访客，即时！',
	'Live_LinkVisitorLog' => '查看详细的访客记录',
	'Live_Actions' => '动作',
	'Live_Action' => '动作',
	'Live_VisitorLog' => '访客记录',
	'Live_Time' => '时间',
	'Live_Referrer_URL' => '推荐链接',
	'Live_GoalType' => '类型',
	'Live_GoalTime' => '第一次转换时间',
	'Live_GoalRevenue' => '价值',
	'Live_GoalDetails' => '详细',
	'Login_PluginDescription' => '登录凭证插件，超级使用者从 config/config.inc.php 文档读取凭证，其他使用者则从数据库。可以很容易取代或导入新的验证机制（OpenID, htaccess, 自定义验证等等）。',
	'Login_LoginPasswordNotCorrect' => '用户名称与密码不正确！',
	'Login_Password' => '密码',
	'Login_PasswordRepeat' => '密码（再次输入）',
	'Login_ChangePassword' => '变更密码',
	'Login_LoginOrEmail' => '登录账号或 E-mail',
	'Login_RememberMe' => '记住密码',
	'Login_LogIn' => '登录',
	'Login_Logout' => '注销',
	'Login_LostYourPassword' => '遗失了您的密码吗?',
	'Login_RemindPassword' => '记忆密码',
	'Login_PasswordResetToken' => '密码重置凭证',
	'Login_PasswordReminder' => '请输入您的用户名称或 E-mail 地址！ 您将透过 E-mail 接收到一组新密码！',
	'Login_PasswordsDoNotMatch' => '密码不相符。',
	'Login_PasswordSuccessfullyChanged' => '密码已成功变更！',
	'Login_InvalidUsernameEmail' => '无效的使用者名称 和/或 E-mail 地址',
	'Login_InvalidNonceOrHeadersOrReferer' => '表单安全检查失败，请重新打开表单，检查是否启用cookie。如果配置了代理服务器，需要 %s 设置Piwik接收代理头信息 %s ，同时检查Referer头是否正确',
	'Login_InvalidOrExpiredToken' => '凭证无效或已经过期。',
	'Login_MailTopicPasswordRecovery' => '重取得密码',
	'Login_MailPasswordRecoveryBody' => '%1$s 您好，%2$s 收到了一个密码重置请求。若要重新设定您的密码：1) 前往密码重设表单: %3$s 2) 输入以下凭证：%4$s 3) 填妥表单（输入您的新密码两次）然后送出。注意：凭证将在 24 小时后过期。',
	'Login_PasswordSent' => '密码刚刚已经发送！ 请检查您的 E-mail 信箱！',
	'Login_ContactAdmin' => '可能的原因：您的主机可能已经停用了 mail() 函数！ <br />请联络您的 Piwik 管理员！',
	'Login_ExceptionPasswordMD5HashExpected' => '密码参数是一个 MD5 加密的密码。',
	'Login_ExceptionInvalidSuperUserAuthenticationMethod' => '超级使用者无法以 \'%s\' 机制通过身份验证。',
	'Mobile_AnonymousAccess' => '匿名访问',
	'Mobile_AccessUrlLabel' => 'Piwik 存取网址',
	'Mobile_EnableGraphsLabel' => '显示图表',
	'Mobile_MultiChartLabel' => '显示 sparklines',
	'Mobile_NetworkNotReachable' => '网络无法访问',
	'Mobile_SaveSuccessError' => '请确认设置',
	'Mobile_YouAreOffline' => '抱歉，您目前离线状态',
	'MultiSites_PluginDescription' => '显示多个网站的摘要 / 统计。目前为 Piwik 的核心插件。',
	'MultiSites_Evolution' => '发展趋势',
	'Provider_PluginDescription' => '访客的联接网络服务供应商报表。',
	'Provider_WidgetProviders' => '因特网服务提供商(ISP)',
	'Provider_ColumnProvider' => '供应商',
	'Provider_SubmenuLocationsProvider' => '所在地＆因特网服务提供商(ISP)',
	'Referers_PluginDescription' => '推荐链接网站资料报表：搜索引擎、关键字、网站、广告活动追踪及直接流量。',
	'Referers_Referers' => '推介网站',
	'Referers_SearchEngines' => '搜索引擎',
	'Referers_Keywords' => '关键词',
	'Referers_DirectEntry' => '直接链接',
	'Referers_Websites' => '网站',
	'Referers_Campaigns' => '广告活动',
	'Referers_Evolution' => '此统计周期的发展趋势',
	'Referers_Type' => '推介网站类型',
	'Referers_ColumnRefererType' => '推荐网站类型',
	'Referers_ColumnSearchEngine' => '搜索引擎',
	'Referers_ColumnWebsite' => '网站',
	'Referers_ColumnWebsitePage' => '网站页面',
	'Referers_ColumnKeyword' => '关键字',
	'Referers_ColumnCampaign' => '广告活动',
	'Referers_DetailsByRefererType' => '推荐网站类型详细资料',
	'Referers_TypeDirectEntries' => '%s 个来自直接链接',
	'Referers_TypeSearchEngines' => '%s 个来自搜索引擎',
	'Referers_TypeWebsites' => '%s 个来自网站',
	'Referers_TypeCampaigns' => '%s 个来自广告活动',
	'Referers_Distinct' => '推荐网站类型的不同参照項目',
	'Referers_DistinctSearchEngines' => '不同的搜索引擎',
	'Referers_DistinctKeywords' => '不同的关键字',
	'Referers_DistinctCampaigns' => '不同的广告活动',
	'Referers_DistinctWebsites' => '不同的网站',
	'Referers_UsingNDistinctUrls' => '(使用 %s 不同的网址)',
	'Referers_SubmenuSearchEngines' => '搜索引擎＆关键词',
	'Referers_SubmenuWebsites' => '网站',
	'Referers_SubmenuCampaigns' => '广告活动',
	'Referers_WidgetKeywords' => '关键词列表',
	'Referers_WidgetCampaigns' => '广告活动清单',
	'Referers_WidgetExternalWebsites' => '外来网站清单',
	'Referers_WidgetSearchEngines' => '最佳搜索引擎',
	'Referers_WidgetOverview' => '概述',
	'SecurityInfo_PluginDescription' => '基于 PhpSecInfo 从 PHP 安全协会，这个插件提供安全性资讯，并提供您的PHP环境改善建议。它是一个多层次的安全工具。它不会从源码 / 应用程序来取代。',
	'SecurityInfo_Security' => '安全性',
	'SecurityInfo_SecurityInformation' => 'PHP 安全性咨询',
	'SecurityInfo_Test' => '测试',
	'SecurityInfo_Result' => '结果',
	'SEO_SeoRankings' => 'SEO 评比',
	'SEO_AlexaRank' => 'Alexa 排名',
	'SEO_DomainAge' => '网域名称年龄',
	'SEO_Rank' => '评比',
	'SEO_Backlinks' => '反向链接',
	'SEO_Pages' => '页面',
	'SEO_SEORankingsFor' => '%s 的 SEO 评比',
	'SitesManager_PluginDescription' => 'Piwik 网站管理：新知一个新网站、编辑一个已存在的网站、显示插入您网页的 JavaScript 源代码。所有动作都可以通过 API 使用。',
	'SitesManager_Sites' => '网站',
	'SitesManager_TrackingTags' => '%s 的追踪程序代码',
	'SitesManager_WebsitesManagement' => '网站管理',
	'SitesManager_MainDescription' => '要使用网站分析报告功能，必须先要有一个网站！增加、更新、删除网站，并显示需要插入网页代码里面的 Javascript 统计代码。',
	'SitesManager_JsTrackingTag' => 'JavaScript 追踪程序代码',
	'SitesManager_JsTrackingTagHelp' => '这是插入所有页面的 JavaScript 追踪源码',
	'SitesManager_ShowTrackingTag' => '显示追踪程序代码',
	'SitesManager_NoWebsites' => '您没有任何网站可管理！',
	'SitesManager_AddSite' => '增加一个新网站',
	'SitesManager_NotFound' => '找不到网站',
	'SitesManager_AliasUrlHelp' => '这是建议，但不是必须，定义一些您的访客进入此网站时可能的网址，一行一个。网站的网址別名将不会显示在推荐链接 > 网站报表里。注意 Piwik 能兼容包含及不包含 \'www\' 的网址。',
	'SitesManager_Urls' => 'URL 地址',
	'SitesManager_MenuSites' => '网站',
	'SitesManager_DeleteConfirm_js' => '您确定要删除网站 %s 吗？',
	'SitesManager_ExceptionDeleteSite' => '不可能删除这个网站，因为它是唯一注册的网站！',
	'SitesManager_ExceptionNoUrl' => '您必须为此网站指定至少一个 URL 地址！',
	'SitesManager_ExceptionEmptyName' => '网站名称不可为空！',
	'SitesManager_ExceptionInvalidUrl' => '此 URL 地址 \'%s\' 并非一个有效的 URL 地址！',
	'SitesManager_ExceptionInvalidTimezone' => '时区 "%s" 无效。请输入正确的时区。',
	'SitesManager_ExceptionInvalidCurrency' => '货币 "%s" 无效。请输入正确的货币符号（例如 %s）',
	'SitesManager_ExceptionInvalidIPFormat' => '欲排除的 IP "%s" 不符合有效的 IP 格式（例如 %s）。',
	'SitesManager_SuperUserCan' => '超级使用者也可以为新网站 %s 指定全局设定%s。',
	'SitesManager_ExcludedIps' => '排除 IP',
	'SitesManager_GlobalListExcludedIps' => '全局排除的 IP 列表',
	'SitesManager_ListOfIpsToBeExcludedOnAllWebsites' => '以下的 IP 位址将会被所有网站忽略。',
	'SitesManager_ExcludedParameters' => '排除参数',
	'SitesManager_GlobalListExcludedQueryParameters' => '全局排除的参数列表',
	'SitesManager_ListOfQueryParametersToBeExcludedOnAllWebsites' => '以下的网址查询参数将会被所有网站忽略。',
	'SitesManager_ListOfQueryParametersToExclude' => '输入网站查詢參數列表，一行一个，用来将特定网址排除在报告之外。',
	'SitesManager_PiwikWillAutomaticallyExcludeCommonSessionParameters' => 'Piwik 将会自动排除常见的会话參數 (%s)。',
	'SitesManager_HelpExcludedIps' => '输入 IP 列表，一行一个，使 Piwik 不追踪特定 IP 位址。您也可以使用通配符, 例如 %1$s 或 %2$s',
	'SitesManager_YourCurrentIpAddressIs' => '您目前的 IP 位址是 %s',
	'SitesManager_SelectACity' => '选择一个城市',
	'SitesManager_ChooseCityInSameTimezoneAsYou' => '选择一个与您目前时区相同的城市。',
	'SitesManager_ChangingYourTimezoneWillOnlyAffectDataForward' => '变更时区仅会影响往后的数据，不会溯及既往。',
	'SitesManager_AdvancedTimezoneSupportNotFound' => '在您的 PHP 找不到进阶时区支持功能（PHP>=5.2 支持）。您还是可以手动选择 UTC。',
	'SitesManager_UTCTimeIs' => 'UTC 时间是 %s.',
	'SitesManager_Timezone' => '时区',
	'SitesManager_GlobalWebsitesSettings' => '全局网站设定',
	'SitesManager_DefaultTimezoneForNewWebsites' => '新网站预设时区',
	'SitesManager_SelectDefaultTimezone' => '您可以为新的网站选择预设的时区。',
	'SitesManager_Currency' => '货币',
	'SitesManager_CurrencySymbolWillBeUsedForGoals' => '货币符号旁将显示目标收益。',
	'SitesManager_DefaultCurrencyForNewWebsites' => '新网站预设货币',
	'SitesManager_SelectDefaultCurrency' => '您可以为新的网站选择预设的货币。',
	'TranslationsAdmin_PluginDescription' => '协助将 Piwik 翻译为您所用的语言。',
	'TranslationsAdmin_MenuTranslations' => '翻译',
	'TranslationsAdmin_MenuLanguages' => '语系',
	'TranslationsAdmin_LanguageCode' => '语系代码',
	'TranslationsAdmin_Plugin' => '插件',
	'TranslationsAdmin_Definition' => '定义',
	'TranslationsAdmin_DefaultString' => '默认字符串 (English)',
	'TranslationsAdmin_TranslationString' => '翻译字符串 (目前的语系: %s)',
	'TranslationsAdmin_Translations' => '翻译',
	'TranslationsAdmin_FixPermissions' => '请修改文件系统权限',
	'TranslationsAdmin_AddLanguage' => '增加语系',
	'TranslationsAdmin_Export' => '汇出语系',
	'TranslationsAdmin_Import' => '汇入语系',
	'UserCountry_PluginDescription' => '访客的来源/国家报表。',
	'UserCountry_Country' => '国家',
	'UserCountry_Continent' => '世界地图',
	'UserCountry_DistinctCountries' => '%s 个不同的国家/地区',
	'UserCountry_Location' => '位置',
	'UserCountry_SubmenuLocations' => '所在地',
	'UserCountry_WidgetContinents' => '访客大陆洲',
	'UserCountry_WidgetCountries' => '访客国家/地区',
	'UserCountry_country_ac' => '英属亚森松岛',
	'UserCountry_country_ad' => '安道尔',
	'UserCountry_country_ae' => '阿拉伯联合大公国',
	'UserCountry_country_af' => '阿富汗',
	'UserCountry_country_ag' => '安地卡及巴布达',
	'UserCountry_country_ai' => '英属安圭拉岛',
	'UserCountry_country_al' => '阿尔巴尼亚',
	'UserCountry_country_am' => '亚美尼亚',
	'UserCountry_country_an' => '荷属安地列斯',
	'UserCountry_country_ao' => '安哥拉',
	'UserCountry_country_aq' => '南极洲',
	'UserCountry_country_ar' => '阿根廷',
	'UserCountry_country_as' => '美属萨摩亚群岛',
	'UserCountry_country_at' => '奥地利',
	'UserCountry_country_au' => '澳洲',
	'UserCountry_country_aw' => '阿鲁巴岛',
	'UserCountry_country_ax' => '奧蘭群島',
	'UserCountry_country_az' => '亚塞拜然',
	'UserCountry_country_ba' => '波斯尼亚与赫塞哥维纳',
	'UserCountry_country_bb' => '巴贝多',
	'UserCountry_country_bd' => '孟加拉国',
	'UserCountry_country_be' => '比利时',
	'UserCountry_country_bf' => '布吉纳法索',
	'UserCountry_country_bg' => '保加利亚',
	'UserCountry_country_bh' => '巴林',
	'UserCountry_country_bi' => '蒲隆地',
	'UserCountry_country_bj' => '贝南',
	'UserCountry_country_bl' => '法屬聖巴泰勒米島',
	'UserCountry_country_bm' => '百慕达群岛',
	'UserCountry_country_bn' => '文莱',
	'UserCountry_country_bo' => '波利维亚',
	'UserCountry_country_br' => '巴西',
	'UserCountry_country_bs' => '巴哈马',
	'UserCountry_country_bt' => '不丹',
	'UserCountry_country_bu' => '緬甸',
	'UserCountry_country_bv' => '波怀特岛',
	'UserCountry_country_bw' => '波札那',
	'UserCountry_country_by' => '白俄罗斯',
	'UserCountry_country_bz' => '贝里斯',
	'UserCountry_country_ca' => '加拿大',
	'UserCountry_country_cc' => '可可斯群岛',
	'UserCountry_country_cd' => '刚果民主主义共和国',
	'UserCountry_country_cf' => '中非共和国',
	'UserCountry_country_cg' => '刚果共和国',
	'UserCountry_country_ch' => '瑞士',
	'UserCountry_country_ci' => '科特迪瓦',
	'UserCountry_country_ck' => '库克群岛',
	'UserCountry_country_cl' => '智利',
	'UserCountry_country_cm' => '喀麦隆',
	'UserCountry_country_cn' => '中国',
	'UserCountry_country_co' => '哥伦比亚',
	'UserCountry_country_cp' => '克利珀頓島',
	'UserCountry_country_cr' => '哥斯达黎加',
	'UserCountry_country_cs' => '塞尔维亚蒙特内哥罗',
	'UserCountry_country_cu' => '古巴',
	'UserCountry_country_cv' => '维德角共和国',
	'UserCountry_country_cx' => '圣诞岛',
	'UserCountry_country_cy' => '塞浦路斯',
	'UserCountry_country_cz' => '捷克共和国',
	'UserCountry_country_de' => '德国',
	'UserCountry_country_dg' => '英屬迪亞哥加西亞島',
	'UserCountry_country_dj' => '吉布提',
	'UserCountry_country_dk' => '丹麦',
	'UserCountry_country_dm' => '多米尼克',
	'UserCountry_country_do' => '多米尼加共和国',
	'UserCountry_country_dz' => '阿尔及利亚',
	'UserCountry_country_ea' => '西屬北非休達與梅利利亞城',
	'UserCountry_country_ec' => '厄瓜多',
	'UserCountry_country_ee' => '爱沙尼亚',
	'UserCountry_country_eg' => '埃及',
	'UserCountry_country_eh' => '西撒哈拉',
	'UserCountry_country_er' => '厄立特里亚',
	'UserCountry_country_es' => '西班牙',
	'UserCountry_country_et' => '衣索比亚',
	'UserCountry_country_eu' => '歐盟',
	'UserCountry_country_fi' => '芬兰',
	'UserCountry_country_fj' => '斐济',
	'UserCountry_country_fk' => '福克兰群岛 (马尔维纳斯群岛)',
	'UserCountry_country_fm' => '密克罗尼西亚联邦',
	'UserCountry_country_fo' => '法罗群岛',
	'UserCountry_country_fr' => '法国',
	'UserCountry_country_fx' => '法屬美特羅波利坦',
	'UserCountry_country_ga' => '加彭',
	'UserCountry_country_gb' => '大不列顛',
	'UserCountry_country_gd' => '格瑞纳达',
	'UserCountry_country_ge' => '乔治亚',
	'UserCountry_country_gf' => '法属圭亚那',
	'UserCountry_country_gg' => '根息岛(根息乳牛岛)',
	'UserCountry_country_gh' => '迦纳',
	'UserCountry_country_gi' => '直布罗陀',
	'UserCountry_country_gl' => '格陵兰',
	'UserCountry_country_gm' => '甘比亚',
	'UserCountry_country_gn' => '几内亚',
	'UserCountry_country_gp' => '瓜德鲁普岛',
	'UserCountry_country_gq' => '赤道几内亚',
	'UserCountry_country_gr' => '希腊',
	'UserCountry_country_gs' => '南乔治亚及南桑威奇群岛',
	'UserCountry_country_gt' => '危地马拉',
	'UserCountry_country_gu' => '关岛',
	'UserCountry_country_gw' => '几内亚比绍',
	'UserCountry_country_gy' => '圭亚那',
	'UserCountry_country_hk' => '香港',
	'UserCountry_country_hm' => '赫德及麦当劳群岛',
	'UserCountry_country_hn' => '宏都拉斯',
	'UserCountry_country_hr' => '克罗埃西亚',
	'UserCountry_country_ht' => '海地',
	'UserCountry_country_hu' => '匈牙利',
	'UserCountry_country_ic' => '西屬加那利群島自治區',
	'UserCountry_country_id' => '印度尼西亚',
	'UserCountry_country_ie' => '爱尔兰',
	'UserCountry_country_il' => '以色列',
	'UserCountry_country_im' => '曼岛',
	'UserCountry_country_in' => '印度',
	'UserCountry_country_io' => '英属印度洋领地(不列颠群岛)',
	'UserCountry_country_iq' => '伊拉克',
	'UserCountry_country_ir' => '伊朗',
	'UserCountry_country_is' => '冰岛',
	'UserCountry_country_it' => '意大利',
	'UserCountry_country_je' => '泽西岛',
	'UserCountry_country_jm' => '牙买加',
	'UserCountry_country_jo' => '约旦',
	'UserCountry_country_jp' => '日本',
	'UserCountry_country_ke' => '肯亚',
	'UserCountry_country_kg' => '吉尔吉斯斯坦',
	'UserCountry_country_kh' => '柬埔寨',
	'UserCountry_country_ki' => '吉里巴斯',
	'UserCountry_country_km' => '科摩洛',
	'UserCountry_country_kn' => '圣克里斯多福及尼维斯群岛',
	'UserCountry_country_kp' => '北韩',
	'UserCountry_country_kr' => '南韩',
	'UserCountry_country_kw' => '科威特',
	'UserCountry_country_ky' => '开曼群岛',
	'UserCountry_country_kz' => '哈萨克',
	'UserCountry_country_la' => '寮国',
	'UserCountry_country_lb' => '黎巴嫩',
	'UserCountry_country_lc' => '圣路西亚岛',
	'UserCountry_country_li' => '列支敦斯登',
	'UserCountry_country_lk' => '斯里兰卡',
	'UserCountry_country_lr' => '赖比瑞亚',
	'UserCountry_country_ls' => '赖索托',
	'UserCountry_country_lt' => '立陶宛',
	'UserCountry_country_lu' => '卢森堡',
	'UserCountry_country_lv' => '拉脱维亚',
	'UserCountry_country_ly' => '利比亚',
	'UserCountry_country_ma' => '摩洛哥',
	'UserCountry_country_mc' => '摩纳哥',
	'UserCountry_country_md' => '摩尔多瓦共和国',
	'UserCountry_country_me' => '蒙特內哥羅',
	'UserCountry_country_mf' => '聖馬丁',
	'UserCountry_country_mg' => '马达加斯加',
	'UserCountry_country_mh' => '马绍尔群岛',
	'UserCountry_country_mk' => '马其顿',
	'UserCountry_country_ml' => '马利',
	'UserCountry_country_mm' => '缅甸',
	'UserCountry_country_mn' => '蒙古国',
	'UserCountry_country_mo' => '澳门',
	'UserCountry_country_mp' => '北马里亚纳群岛',
	'UserCountry_country_mq' => '法属马丁尼克岛',
	'UserCountry_country_mr' => '毛里塔尼亚伊斯兰共和国',
	'UserCountry_country_ms' => '蒙特色纳岛',
	'UserCountry_country_mt' => '马耳他',
	'UserCountry_country_mu' => '模里西斯',
	'UserCountry_country_mv' => '马尔地夫',
	'UserCountry_country_mw' => '马拉威',
	'UserCountry_country_mx' => '墨西哥',
	'UserCountry_country_my' => '马来西亚',
	'UserCountry_country_mz' => '莫桑比克',
	'UserCountry_country_na' => '纳米比亚',
	'UserCountry_country_nc' => '新喀里多尼亚',
	'UserCountry_country_ne' => '尼日',
	'UserCountry_country_nf' => '诺福克岛',
	'UserCountry_country_ng' => '奈及利亚',
	'UserCountry_country_ni' => '尼加拉瓜',
	'UserCountry_country_nl' => '荷兰',
	'UserCountry_country_no' => '挪威',
	'UserCountry_country_np' => '尼泊尔',
	'UserCountry_country_nr' => '诺鲁',
	'UserCountry_country_nt' => '中立區',
	'UserCountry_country_nu' => '纽埃岛',
	'UserCountry_country_nz' => '纽西兰',
	'UserCountry_country_om' => '阿曼',
	'UserCountry_country_pa' => '巴拿马',
	'UserCountry_country_pe' => '秘鲁',
	'UserCountry_country_pf' => '法属玻里尼西亚',
	'UserCountry_country_pg' => '巴布亚纽几内亚',
	'UserCountry_country_ph' => '菲律宾',
	'UserCountry_country_pk' => '巴基斯坦',
	'UserCountry_country_pl' => '波兰',
	'UserCountry_country_pm' => '法属圣皮埃尔密克隆群岛',
	'UserCountry_country_pn' => '英属匹特开恩岛',
	'UserCountry_country_pr' => '波多黎各',
	'UserCountry_country_ps' => '巴勒斯坦',
	'UserCountry_country_pt' => '葡萄牙',
	'UserCountry_country_pw' => '帛琉',
	'UserCountry_country_py' => '巴拉圭',
	'UserCountry_country_qa' => '卡达',
	'UserCountry_country_re' => '法属留尼旺岛',
	'UserCountry_country_ro' => '罗马尼亚',
	'UserCountry_country_rs' => '俄罗斯',
	'UserCountry_country_ru' => '俄罗斯联邦',
	'UserCountry_country_rw' => '卢安达',
	'UserCountry_country_sa' => '沙特阿拉伯',
	'UserCountry_country_sb' => '索罗门群岛',
	'UserCountry_country_sc' => '塞席尔群岛',
	'UserCountry_country_sd' => '苏丹',
	'UserCountry_country_se' => '瑞典',
	'UserCountry_country_sf' => '芬蘭',
	'UserCountry_country_sg' => '新加坡',
	'UserCountry_country_sh' => '英属圣赫勒拿岛',
	'UserCountry_country_si' => '斯洛维尼亚',
	'UserCountry_country_sj' => '冷岸群岛(斯瓦尔巴和扬马延群岛)',
	'UserCountry_country_sk' => '斯洛伐克',
	'UserCountry_country_sl' => '狮子山共和国',
	'UserCountry_country_sm' => '圣马力诺',
	'UserCountry_country_sn' => '塞内加尔',
	'UserCountry_country_so' => '索马利亚',
	'UserCountry_country_sr' => '苏利南',
	'UserCountry_country_st' => '圣多美普林西比',
	'UserCountry_country_su' => '旧苏联',
	'UserCountry_country_sv' => '萨尔瓦多',
	'UserCountry_country_sy' => '叙利亚',
	'UserCountry_country_sz' => '史瓦济兰',
	'UserCountry_country_ta' => '英屬特里斯坦達庫尼亞群島',
	'UserCountry_country_tc' => '土克斯及开科斯群岛',
	'UserCountry_country_td' => '查德',
	'UserCountry_country_tf' => '法属南极领地',
	'UserCountry_country_tg' => '多哥',
	'UserCountry_country_th' => '泰国',
	'UserCountry_country_tj' => '塔吉克',
	'UserCountry_country_tk' => '托克劳群岛',
	'UserCountry_country_tl' => '東帝汶',
	'UserCountry_country_tm' => '土库曼',
	'UserCountry_country_tn' => '突尼西亚',
	'UserCountry_country_to' => '东加王国',
	'UserCountry_country_tp' => '东帝汶',
	'UserCountry_country_tr' => '土耳其',
	'UserCountry_country_tt' => '千里达托贝哥',
	'UserCountry_country_tv' => '吐瓦鲁',
	'UserCountry_country_tw' => '台湾地区',
	'UserCountry_country_tz' => '坦尚尼亚',
	'UserCountry_country_ua' => '乌克兰',
	'UserCountry_country_ug' => '乌干达',
	'UserCountry_country_uk' => '英国',
	'UserCountry_country_um' => '美属澳特兰群岛',
	'UserCountry_country_us' => '美国',
	'UserCountry_country_uy' => '乌拉圭',
	'UserCountry_country_uz' => '乌兹别克斯坦',
	'UserCountry_country_va' => '梵谛冈',
	'UserCountry_country_vc' => '圣文森',
	'UserCountry_country_ve' => '委内瑞拉',
	'UserCountry_country_vg' => '英属维尔京群岛',
	'UserCountry_country_vi' => '美属维京群岛',
	'UserCountry_country_vn' => '越南',
	'UserCountry_country_vu' => '万那杜',
	'UserCountry_country_wf' => '瓦利斯富图纳群岛',
	'UserCountry_country_ws' => '西萨摩亚',
	'UserCountry_country_ye' => '也门',
	'UserCountry_country_yt' => '马约特岛岛',
	'UserCountry_country_yu' => '南斯拉夫',
	'UserCountry_country_za' => '南非',
	'UserCountry_country_zm' => '赞比亚',
	'UserCountry_country_zr' => '扎伊尔',
	'UserCountry_country_zw' => '津巴布韦',
	'UserCountry_continent_eur' => '欧洲',
	'UserCountry_continent_afr' => '非洲',
	'UserCountry_continent_asi' => '亚洲',
	'UserCountry_continent_amn' => '北美洲',
	'UserCountry_continent_ams' => '中南美洲',
	'UserCountry_continent_oce' => '大洋洲',
	'UserCountryMap_map' => '地图',
	'UserCountryMap_worldMap' => '世界地图',
	'UserCountryMap_toggleFullscreen' => '切换全屏幕',
	'UserSettings_PluginDescription' => '各个用户设定报表：浏览器、浏览器家族、操作系统、插件、分辨率、全局设定。',
	'UserSettings_VisitorSettings' => '访客设置',
	'UserSettings_BrowserFamilies' => '浏览器家族',
	'UserSettings_Browsers' => '使用浏览器',
	'UserSettings_Plugins' => '浏览器插件',
	'UserSettings_Configurations' => '客户端配置',
	'UserSettings_OperatingSystems' => '操作系统',
	'UserSettings_Resolutions' => '分辨率',
	'UserSettings_WideScreen' => '宽屏幕',
	'UserSettings_ColumnBrowserFamily' => '浏览器家族',
	'UserSettings_ColumnBrowser' => '浏览器',
	'UserSettings_ColumnPlugin' => '插件',
	'UserSettings_ColumnConfiguration' => '客戶端配置',
	'UserSettings_ColumnOperatingSystem' => '操作系统',
	'UserSettings_ColumnResolution' => '分辨率',
	'UserSettings_ColumnTypeOfScreen' => '屏幕类型',
	'UserSettings_WidgetResolutions' => '画面分辨率',
	'UserSettings_WidgetBrowsers' => '使用浏览器',
	'UserSettings_WidgetPlugins' => '浏览器插件清单',
	'UserSettings_PluginDetectionDoesNotWorkInIE' => '注意：插件检查无法在 Internet Explorer 上运行。这个报告仅提供非 IE 浏览器。',
	'UserSettings_WidgetWidescreen' => '传统屏幕 / 宽屏幕',
	'UserSettings_WidgetBrowserFamilies' => '浏览器依家族分',
	'UserSettings_WidgetOperatingSystems' => '操作系统',
	'UserSettings_WidgetGlobalVisitors' => '全球访问者配置',
	'UserSettings_SubmenuSettings' => '环境设定值',
	'UsersManager_PluginDescription' => 'Piwik 使用者管理：新增一个新使用者、编辑已存在的使用者或更新权限。所有动作也可以通过 API 进行。',
	'UsersManager_UsersManagement' => '用户管理',
	'UsersManager_UsersManagementMainDescription' => '建立新的用户或更新现存的用户，然后您就可以设定他们的权限。',
	'UsersManager_ManageAccess' => '权限管理',
	'UsersManager_MainDescription' => '设置在您网站上的哪个用户具有哪些 Piwik 权限。 您也可以一次设定所有网站的权限。',
	'UsersManager_Sites' => '网站',
	'UsersManager_AllWebsites' => '所有网站',
	'UsersManager_ApplyToAllWebsites' => '应用至所有网站',
	'UsersManager_User' => '用户',
	'UsersManager_PrivNone' => '无权限',
	'UsersManager_PrivView' => '查看',
	'UsersManager_PrivAdmin' => '管理员',
	'UsersManager_ChangeAllConfirm' => '您确定要在所有网站上变更 \'%s\' 的权限吗？',
	'UsersManager_Password' => '密码',
	'UsersManager_Email' => 'E-mail',
	'UsersManager_Alias' => '别名',
	'UsersManager_TheSuperUserAliasCannotBeChanged' => '超级使用者的別名无法变更。',
	'UsersManager_ReportToLoadByDefault' => '预设载入报表',
	'UsersManager_ReportDateToLoadByDefault' => '预设载入日期',
	'UsersManager_ForAnonymousUsersReportDateToLoadByDefault' => '对于匿名用戶预设载入日期',
	'UsersManager_ExcludeVisitsViaCookie' => '以 cookie 排除您的访问记录',
	'UsersManager_YourVisitsAreIgnoredOnDomain' => '%s您的访问记录已在 %s %s 被 Piwik 忽略（在您的浏览器找到 Piwik 拒绝 cookie）',
	'UsersManager_YourVisitsAreNotIgnored' => '%s您的访问记录沒有被 Piwik 忽略%s（在您的浏览器找不到 Piwik 拒绝 cookie）',
	'UsersManager_ClickHereToDeleteTheCookie' => '点击这里刪除 cookie 并让 Piwik 追踪您的访问记录',
	'UsersManager_ClickHereToSetTheCookieOnDomain' => '点击这里设定一个 cookie 让 %s 的 Piwik 排除您的访问记录',
	'UsersManager_Edit' => '编辑',
	'UsersManager_AddUser' => '增加一个新用户',
	'UsersManager_MenuUsers' => '用户',
	'UsersManager_MenuUserSettings' => '使用者设定',
	'UsersManager_MenuAnonymousUserSettings' => '匿名用戶设定',
	'UsersManager_NoteNoAnonymousUserAccessSettingsWontBeUsed' => '注意：您沒有任何网站能让匿名用戶存取，以下设定将无效。',
	'UsersManager_WhenUsersAreNotLoggedInAndVisitPiwikTheyShouldAccess' => '当使用者未登录且访问 Piwik 时，他们应该前往',
	'UsersManager_ChangePassword' => '变更密码',
	'UsersManager_IfYouWouldLikeToChangeThePasswordTypeANewOne' => '如果您要变更密码时请输入新的密码。否则留空。',
	'UsersManager_TypeYourPasswordAgain' => '再输入一次新的密码。',
	'UsersManager_TheLoginScreen' => '登录界面',
	'UsersManager_DeleteConfirm_js' => '您确定要删除 %s 用户吗？',
	'UsersManager_YourUsernameCannotBeChanged' => '您的使用者名称无法变更。',
	'UsersManager_ExceptionLoginExists' => '登录账号 \'%s\' 已经存在！',
	'UsersManager_ExceptionEmailExists' => '使用 \'%s\' E-mail 的使用者已经存在！',
	'UsersManager_ExceptionInvalidLoginFormat' => '登录帐号的长度必须介于 %1$s 至 %2$s 字符之间，并且只能包含字母、数字或字符 \'_\' 或 \'-\' 或 \'.\' 。',
	'UsersManager_ExceptionInvalidEmail' => '此 E-mail 并非一个正确格式！',
	'UsersManager_ExceptionDeleteDoesNotExist' => '用户 \'%s\' 并不存在，所以它不能被删除！',
	'UsersManager_ExceptionAdminAnonymous' => '您不能授予 \'管理员\' 权限给 \'anonymous\' 用户！',
	'UsersManager_ExceptionEditAnonymous' => 'anonymous 用户不能被修改或删除，因为他是被 Piwik 使用来定义一个还未登入的用户！例如，您可以授予 \'查看\' 访问权限给 \'anonymous\' 用户以公开您的统计资料！',
	'UsersManager_ExceptionSuperUser' => '請求的使用者為超級使用者且無法被查詢，請透過應用程式介面 API 編輯或刪除。 您可以在您的 Piwik 設定檔手動編輯超級使用者。',
	'UsersManager_ExceptionUserDoesNotExist' => '用户 \'%s\' 并不存在！',
	'UsersManager_ExceptionAccessValues' => '参数必须有一个以下的值： [ %s ]',
	'UsersManager_ExceptionPasswordMD5HashExpected' => 'UsersManager.getTokenAuth 是以MD5加密的密碼（32個字元字串）。在使用此方法前请先调用 md5()函数。',
	'VisitFrequency_PluginDescription' => '关于回访者与一般访客的报表。',
	'VisitFrequency_Evolution' => '此统计周期的发展趋势',
	'VisitFrequency_ColumnReturningVisits' => '重返访问数',
	'VisitFrequency_ColumnActionsByReturningVisits' => '重返访问的活动数',
	'VisitFrequency_ColumnAverageVisitDurationForReturningVisitors' => '重返访问的平均访问时间（以秒为单位）',
	'VisitFrequency_ColumnBounceRateForReturningVisits' => '重返访问的跳出率',
	'VisitFrequency_ColumnAvgActionsPerReturningVisit' => '每个重返访问的平均活动数',
	'VisitFrequency_ReturnVisits' => '%s 个重返访问数',
	'VisitFrequency_ReturnActions' => '%s 个活动数由重返访问所产生',
	'VisitFrequency_ReturnAvgActions' => '%s 个活动数每个重返访问',
	'VisitFrequency_ReturnAverageVisitDuration' => '%s 重返访问的平均访问時間',
	'VisitFrequency_ReturnBounceRate' => '%s 重返访问者的跳出数 (浏览一个页面后就离开网站)',
	'VisitFrequency_WidgetOverview' => '频率概述',
	'VisitFrequency_WidgetGraphReturning' => '重返访问者走势',
	'VisitFrequency_SubmenuFrequency' => '频率',
	'VisitorGenerator_PluginDescription' => '这个插件用于建立假的访客。这可以让 Piwik 使用者或开发人员轻松产生假的资料来填充 Piwik 报表。',
	'VisitorGenerator_VisitorGenerator' => '访客产生器',
	'VisitorGenerator_Warning' => '您将产生的假访客将会记录在您的 Piwik 数据库里。',
	'VisitorGenerator_NotReversible' => '它可能%s无法%s简单地从 piwik 记录中刪除。',
	'VisitorGenerator_AreYouSure' => '您确定要产生假的访客吗？',
	'VisitorGenerator_ChoiceYes' => '是，我确定！',
	'VisitorGenerator_Submit' => '送出',
	'VisitorGenerator_SelectWebsite' => '选择网站',
	'VisitorGenerator_NbRequestsPerSec' => '每秒请求数',
	'VisitorGenerator_DaysToCompute' => '计算天数',
	'VisitorInterest_PluginDescription' => '关于访客兴趣的报表：页面浏览次数、及花多少时间在网站里。',
	'VisitorInterest_VisitsPerDuration' => '各个访问停留时间的访问次数',
	'VisitorInterest_VisitsPerNbOfPages' => '各个浏览页面数的访问次数',
	'VisitorInterest_ColumnVisitDuration' => '访问停留时间',
	'VisitorInterest_ColumnPagesPerVisit' => '每次访问浏览的页面数',
	'VisitorInterest_WidgetLengths' => '访问停留时间',
	'VisitorInterest_WidgetPages' => '页/每访问',
	'VisitorInterest_Engagement' => '忠诚度',
	'VisitorInterest_PlusXMin' => '%s 分',
	'VisitorInterest_BetweenXYMinutes' => '%1$s-%2$s 分',
	'VisitorInterest_OnePage' => '1 页',
	'VisitorInterest_NPages' => '%s 页',
	'VisitorInterest_BetweenXYSeconds' => '%1$s-%2$s 秒',
	'VisitsSummary_PluginDescription' => '一般分析項目报告：访问次数、绝对不重复访客、活动数、跳出率等等。',
	'VisitsSummary_VisitsSummary' => '访客概述',
	'VisitsSummary_NbVisits' => '%s 访客数',
	'VisitsSummary_NbUniqueVisitors' => '%s 绝对唯一访客数',
	'VisitsSummary_NbActionsDescription' => '%s 个活动（检测网页、下载和离开链接）',
	'VisitsSummary_AverageVisitDuration' => '%s 平均访问时间',
	'VisitsSummary_MaxNbActions' => '%s 在一次会话中最大活动数',
	'VisitsSummary_NbActionsPerVisit' => '%s 每个访客的活动数',
	'VisitsSummary_NbVisitsBounced' => '%s 已经跳出的访客数 (浏览一个页面以后就离开网站)',
	'VisitsSummary_EvolutionOverLastPeriods' => '最近的发展趋势 %s',
	'VisitsSummary_GenerateTime' => '%s 秒来生成这个页面',
	'VisitsSummary_GenerateQueries' => '%s 查询已执行',
	'VisitsSummary_WidgetLastVisits' => '最近访问者走势图',
	'VisitsSummary_WidgetVisits' => '访问者概述',
	'VisitsSummary_WidgetLastVisitors' => '最近唯一访客走势图',
	'VisitsSummary_WidgetOverviewGraph' => '走势图概述',
	'VisitsSummary_SubmenuOverview' => '概述',
	'VisitTime_PluginDescription' => '当地时段及服务器时段报表。服务器时段能作为排定网站维护时间的參考。',
	'VisitTime_LocalTime' => '依客户端时段记录的访问次数',
	'VisitTime_ServerTime' => '依服务器时段记录的访问次数',
	'VisitTime_ColumnServerTime' => '服务器时段',
	'VisitTime_ColumnLocalTime' => '客户端时段',
	'VisitTime_WidgetLocalTime' => '依客户端时段记录的访问次数',
	'VisitTime_WidgetServerTime' => '依服务器时段记录的访问次数',
	'VisitTime_SubmenuTimes' => '访问时段',
	'VisitTime_NHour' => '%s时',
	'Widgetize_PluginDescription' => '这个插件让您轻松输出任何 Piwik 模组至您的博客、网站或 iGoogle 及 Netvibes!',
	'PDFReports_PDF' => 'PDF',
	'PDFReports_EmailSchedule' => 'Email 排程',
	'PDFReports_SendReportTo' => '寄送报告至',
	'PDFReports_SentToMe' => '寄给我',
	'PDFReports_WeeklyScheduleHelp' => '每周排程：报表将会在每周的星期一寄出。',
	'PDFReports_MonthlyScheduleHelp' => '每月排程：报表将会在每月的第一天寄出。',
	'PDFReports_AlsoSendReportToTheseEmails' => '也将报表寄到這些电子邮件地址（一行一个信箱）：',
	'PDFReports_PiwikReports' => 'Piwik 報表',
	'PDFReports_EmailHello' => '您好，',
	'PDFReports_PleaseFindAttachedFile' => '请在您的报表 %2$s 找到附件 %1$s 。',
);
